@@ -6,8 +6,6 @@ use warnings;
 use XML::XPathScript::Template;
 use XML::XPathScript::Processor;
 
-our $VERSION = '0.08_04';
-
 our $processor;
 
 our $stylesheet = <<'END_STYLESHEET';
@@ -59,11 +57,7 @@ $template->set( title => {
 sub tc_title {
     my ( $n, $t ) = @_;
 
-    my $abbrev;
-    if ( $n->parentNode->getName eq "sect1" ) {
-         ( $abbrev ) = eval { split '-', $n->childNodes->[0]->toString, 2 };
-    }
-
+    my( $abbrev ) = split '-', $n->childNodes->[0]->toString, 2;
     $t->set({ post => "<titleabbrev>$abbrev</titleabbrev>" }) if $abbrev;
 
     return   $n->findvalue( 'text()' ) eq 'DESCRIPTION'
@@ -73,50 +67,43 @@ sub tc_title {
 }
 
 sub action_sect1 {
-    my( $n, $t ) = @_;
-
-    my $title = $n->findvalue( 'title/text()' );
-
-    if ( $title eq 'DESCRIPTION' ) {
-        $t->set({ pre => '', showtag => 0 });
-    }
-
-    return $title eq 'NAME' ? $DO_NOT_PROCESS : $DO_SELF_AND_KIDS ;
+    my $n = shift;
+    return   $n->findvalue( 'title/text()' ) eq 'NAME'
+           ? $DO_NOT_PROCESS 
+           : $DO_SELF_AND_KIDS
+           ;
 }
 
 $template->set( 'item' => { showtag => 0 } );
-$template->set( 'itemtext' => { showtag => 0 } );
+$template->set( 'itemtext' => { action => $DO_NOT_PROCESS } );
 
 sub tc_list {
     my ( $n, $t ) = @_;
     my $output;
 
-    #if ( $n->findnodes( 'item/itemtext' ) ) { # we are a variable list
-    #        $output = '<variablelist>';
-    #        for my $c ( $n->findnodes('item') ) {
-    #            my $item = '<varlistentry>';
-    #            $item .= '<term>' . $c->findvalue( 'term/text()' ) . '</term>';
-    #            $item .= '<listitem>';
-    #            $item .= $processor->apply_templates( $c );
-    #            $item .= '</listitem>';
-    #            $item .= '</varlistentry>';
-    #            $output .= $item;
-    #        }
-    #        $output .= '</variablelist>';
-    #}
-    #else {  # we are a itemized list 
-    $output = '<itemizedlist>';
-
-    for ( $n->findnodes( 'item' ) ) {
-        $output .=  '<listitem>' 
-                .   $processor->apply_templates( $_ )
-                .   '</listitem>'
-                ;
+    if ( $n->findnodes( 'item/itemtext' ) ) { # we are a variable list
+            $output = '<variablelist>';
+            for my $c ( $n->findnodes('item') ) {
+                my $item = '<varlistentry>';
+                $item .= '<term>' . $c->findvalue( 'term/text()' ) . '</term>';
+                $item .= '<listitem>';
+                $item .= $processor->apply_templates( $c );
+                $item .= '</listitem>';
+                $item .= '</varlistentry>';
+                $output .= $item;
+            }
+            $output .= '</variablelist>';
     }
+    else {  # we are a itemized list 
+        $output = '<itemizedlist>';
 
-    $output .= '</itemizedlist>';
+        $output .= '<listitem>' 
+                 . $processor->apply_templates( $_ ) 
+                 . '</listitem>'
+            for $n->findnodes( 'item' );
 
-    #}
+        $output .= '</itemizedlist>';
+    }
 
     $t->{pre} = $output;
 
